'''_354.py

FlankMicroGeometry
'''


from mastapy.gears import _139
from mastapy._internal import constructor, conversion
from mastapy.gears.gear_designs import _703
from mastapy.gears.gear_designs.zerol_bevel import _708
from mastapy._internal.cast_exception import CastException
from mastapy.gears.gear_designs.worm import _712, _713, _716
from mastapy.gears.gear_designs.straight_bevel_diff import _717
from mastapy.gears.gear_designs.straight_bevel import _721
from mastapy.gears.gear_designs.spiral_bevel import _725
from mastapy.gears.gear_designs.klingelnberg_spiral_bevel import _729
from mastapy.gears.gear_designs.klingelnberg_hypoid import _733
from mastapy.gears.gear_designs.klingelnberg_conical import _737
from mastapy.gears.gear_designs.hypoid import _741
from mastapy.gears.gear_designs.face import _745, _750, _753
from mastapy.gears.gear_designs.cylindrical import _767, _788
from mastapy.gears.gear_designs.conical import _879
from mastapy.gears.gear_designs.concept import _901
from mastapy.gears.gear_designs.bevel import _905
from mastapy.gears.gear_designs.agma_gleason_conical import _918
from mastapy import _1
from mastapy._internal.python_net import python_net_import

_FLANK_MICRO_GEOMETRY = python_net_import('SMT.MastaAPI.Gears.MicroGeometry', 'FlankMicroGeometry')


__docformat__ = 'restructuredtext en'
__all__ = ('FlankMicroGeometry',)


class FlankMicroGeometry(_1.APIBase):
    '''FlankMicroGeometry

    This is a mastapy class.
    '''

    TYPE = _FLANK_MICRO_GEOMETRY

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FlankMicroGeometry.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def micro_geometry_input_type(self) -> '_139.MicroGeometryInputTypes':
        '''MicroGeometryInputTypes: 'MicroGeometryInputType' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.MicroGeometryInputType)
        return constructor.new(_139.MicroGeometryInputTypes)(value) if value else None

    @micro_geometry_input_type.setter
    def micro_geometry_input_type(self, value: '_139.MicroGeometryInputTypes'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.MicroGeometryInputType = value

    @property
    def gear_design(self) -> '_703.GearDesign':
        '''GearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_703.GearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_zerol_bevel_gear_design(self) -> '_708.ZerolBevelGearDesign':
        '''ZerolBevelGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _708.ZerolBevelGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to ZerolBevelGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_708.ZerolBevelGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_worm_design(self) -> '_712.WormDesign':
        '''WormDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _712.WormDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to WormDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_712.WormDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_worm_gear_design(self) -> '_713.WormGearDesign':
        '''WormGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _713.WormGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to WormGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_713.WormGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_worm_wheel_design(self) -> '_716.WormWheelDesign':
        '''WormWheelDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _716.WormWheelDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to WormWheelDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_716.WormWheelDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_straight_bevel_diff_gear_design(self) -> '_717.StraightBevelDiffGearDesign':
        '''StraightBevelDiffGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _717.StraightBevelDiffGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to StraightBevelDiffGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_717.StraightBevelDiffGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_straight_bevel_gear_design(self) -> '_721.StraightBevelGearDesign':
        '''StraightBevelGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _721.StraightBevelGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to StraightBevelGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_721.StraightBevelGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_spiral_bevel_gear_design(self) -> '_725.SpiralBevelGearDesign':
        '''SpiralBevelGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _725.SpiralBevelGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to SpiralBevelGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_725.SpiralBevelGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_klingelnberg_cyclo_palloid_spiral_bevel_gear_design(self) -> '_729.KlingelnbergCycloPalloidSpiralBevelGearDesign':
        '''KlingelnbergCycloPalloidSpiralBevelGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _729.KlingelnbergCycloPalloidSpiralBevelGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to KlingelnbergCycloPalloidSpiralBevelGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_729.KlingelnbergCycloPalloidSpiralBevelGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_klingelnberg_cyclo_palloid_hypoid_gear_design(self) -> '_733.KlingelnbergCycloPalloidHypoidGearDesign':
        '''KlingelnbergCycloPalloidHypoidGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _733.KlingelnbergCycloPalloidHypoidGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to KlingelnbergCycloPalloidHypoidGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_733.KlingelnbergCycloPalloidHypoidGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_klingelnberg_conical_gear_design(self) -> '_737.KlingelnbergConicalGearDesign':
        '''KlingelnbergConicalGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _737.KlingelnbergConicalGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to KlingelnbergConicalGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_737.KlingelnbergConicalGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_hypoid_gear_design(self) -> '_741.HypoidGearDesign':
        '''HypoidGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _741.HypoidGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to HypoidGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_741.HypoidGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_face_gear_design(self) -> '_745.FaceGearDesign':
        '''FaceGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _745.FaceGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to FaceGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_745.FaceGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_face_gear_pinion_design(self) -> '_750.FaceGearPinionDesign':
        '''FaceGearPinionDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _750.FaceGearPinionDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to FaceGearPinionDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_750.FaceGearPinionDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_face_gear_wheel_design(self) -> '_753.FaceGearWheelDesign':
        '''FaceGearWheelDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _753.FaceGearWheelDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to FaceGearWheelDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_753.FaceGearWheelDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_cylindrical_gear_design(self) -> '_767.CylindricalGearDesign':
        '''CylindricalGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _767.CylindricalGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to CylindricalGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_767.CylindricalGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_cylindrical_planet_gear_design(self) -> '_788.CylindricalPlanetGearDesign':
        '''CylindricalPlanetGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _788.CylindricalPlanetGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to CylindricalPlanetGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_788.CylindricalPlanetGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_conical_gear_design(self) -> '_879.ConicalGearDesign':
        '''ConicalGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _879.ConicalGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to ConicalGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_879.ConicalGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_concept_gear_design(self) -> '_901.ConceptGearDesign':
        '''ConceptGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _901.ConceptGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to ConceptGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_901.ConceptGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_bevel_gear_design(self) -> '_905.BevelGearDesign':
        '''BevelGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _905.BevelGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to BevelGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_905.BevelGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None

    @property
    def gear_design_of_type_agma_gleason_conical_gear_design(self) -> '_918.AGMAGleasonConicalGearDesign':
        '''AGMAGleasonConicalGearDesign: 'GearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _918.AGMAGleasonConicalGearDesign.TYPE not in self.wrapped.GearDesign.__class__.__mro__:
            raise CastException('Failed to cast gear_design to AGMAGleasonConicalGearDesign. Expected: {}.'.format(self.wrapped.GearDesign.__class__.__qualname__))

        return constructor.new(_918.AGMAGleasonConicalGearDesign)(self.wrapped.GearDesign) if self.wrapped.GearDesign else None



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._717 import StraightBevelDiffGearDesign
    from ._718 import StraightBevelDiffGearMeshDesign
    from ._719 import StraightBevelDiffGearSetDesign
    from ._720 import StraightBevelDiffMeshedGearDesign



'''_1980.py

InternalClearanceTolerance
'''


from mastapy._internal.implicit import enum_with_selected_value
from mastapy.bearings.tolerances import _1514, _1512
from mastapy._internal import conversion, enum_with_selected_value_runtime, constructor
from mastapy import _1
from mastapy._internal.python_net import python_net_import

_INTERNAL_CLEARANCE_TOLERANCE = python_net_import('SMT.MastaAPI.SystemModel.PartModel', 'InternalClearanceTolerance')


__docformat__ = 'restructuredtext en'
__all__ = ('InternalClearanceTolerance',)


class InternalClearanceTolerance(_1.APIBase):
    '''InternalClearanceTolerance

    This is a mastapy class.
    '''

    TYPE = _INTERNAL_CLEARANCE_TOLERANCE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'InternalClearanceTolerance.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def definition_option(self) -> 'enum_with_selected_value.EnumWithSelectedValue_BearingToleranceDefinitionOptions':
        '''enum_with_selected_value.EnumWithSelectedValue_BearingToleranceDefinitionOptions: 'DefinitionOption' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_BearingToleranceDefinitionOptions.implicit_type()
        return enum_with_selected_value_runtime.create(self.wrapped.DefinitionOption, value) if self.wrapped.DefinitionOption else None

    @definition_option.setter
    def definition_option(self, value: 'enum_with_selected_value.EnumWithSelectedValue_BearingToleranceDefinitionOptions.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_BearingToleranceDefinitionOptions.implicit_type().type_()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value if value else None)
        self.wrapped.DefinitionOption = value

    @property
    def clearance_class(self) -> 'enum_with_selected_value.EnumWithSelectedValue_InternalClearanceClass':
        '''enum_with_selected_value.EnumWithSelectedValue_InternalClearanceClass: 'ClearanceClass' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_InternalClearanceClass.implicit_type()
        return enum_with_selected_value_runtime.create(self.wrapped.ClearanceClass, value) if self.wrapped.ClearanceClass else None

    @clearance_class.setter
    def clearance_class(self, value: 'enum_with_selected_value.EnumWithSelectedValue_InternalClearanceClass.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_InternalClearanceClass.implicit_type().type_()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value if value else None)
        self.wrapped.ClearanceClass = value

    @property
    def minimum(self) -> 'float':
        '''float: 'Minimum' is the original name of this property.'''

        return self.wrapped.Minimum

    @minimum.setter
    def minimum(self, value: 'float'):
        self.wrapped.Minimum = float(value) if value else 0.0

    @property
    def maximum(self) -> 'float':
        '''float: 'Maximum' is the original name of this property.'''

        return self.wrapped.Maximum

    @maximum.setter
    def maximum(self, value: 'float'):
        self.wrapped.Maximum = float(value) if value else 0.0



'''_1657.py

PreloadFactorLookupTable
'''


from mastapy._internal import constructor
from mastapy import _1
from mastapy._internal.python_net import python_net_import

_PRELOAD_FACTOR_LOOKUP_TABLE = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling', 'PreloadFactorLookupTable')


__docformat__ = 'restructuredtext en'
__all__ = ('PreloadFactorLookupTable',)


class PreloadFactorLookupTable(_1.APIBase):
    '''PreloadFactorLookupTable

    This is a mastapy class.
    '''

    TYPE = _PRELOAD_FACTOR_LOOKUP_TABLE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PreloadFactorLookupTable.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def high(self) -> 'float':
        '''float: 'High' is the original name of this property.'''

        return self.wrapped.High

    @high.setter
    def high(self, value: 'float'):
        self.wrapped.High = float(value) if value else 0.0

    @property
    def medium(self) -> 'float':
        '''float: 'Medium' is the original name of this property.'''

        return self.wrapped.Medium

    @medium.setter
    def medium(self, value: 'float'):
        self.wrapped.Medium = float(value) if value else 0.0

    @property
    def low(self) -> 'float':
        '''float: 'Low' is the original name of this property.'''

        return self.wrapped.Low

    @low.setter
    def low(self, value: 'float'):
        self.wrapped.Low = float(value) if value else 0.0

    @property
    def zero(self) -> 'float':
        '''float: 'Zero' is the original name of this property.'''

        return self.wrapped.Zero

    @zero.setter
    def zero(self, value: 'float'):
        self.wrapped.Zero = float(value) if value else 0.0



'''_4715.py

CouplingModalAnalysis
'''


from mastapy.system_model.part_model.couplings import (
    _2096, _2091, _2094, _2100,
    _2111, _2118
)
from mastapy._internal import constructor
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.system_deflections import (
    _2224, _2206, _2212, _2273,
    _2294, _2312
)
from mastapy.system_model.analyses_and_results.modal_analyses import _4775
from mastapy._internal.python_net import python_net_import

_COUPLING_MODAL_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses', 'CouplingModalAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('CouplingModalAnalysis',)


class CouplingModalAnalysis(_4775.SpecialisedAssemblyModalAnalysis):
    '''CouplingModalAnalysis

    This is a mastapy class.
    '''

    TYPE = _COUPLING_MODAL_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CouplingModalAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def assembly_design(self) -> '_2096.Coupling':
        '''Coupling: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2096.Coupling)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_clutch(self) -> '_2091.Clutch':
        '''Clutch: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2091.Clutch.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to Clutch. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new(_2091.Clutch)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_concept_coupling(self) -> '_2094.ConceptCoupling':
        '''ConceptCoupling: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2094.ConceptCoupling.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to ConceptCoupling. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new(_2094.ConceptCoupling)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_part_to_part_shear_coupling(self) -> '_2100.PartToPartShearCoupling':
        '''PartToPartShearCoupling: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2100.PartToPartShearCoupling.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to PartToPartShearCoupling. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new(_2100.PartToPartShearCoupling)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_spring_damper(self) -> '_2111.SpringDamper':
        '''SpringDamper: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2111.SpringDamper.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to SpringDamper. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new(_2111.SpringDamper)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_design_of_type_torque_converter(self) -> '_2118.TorqueConverter':
        '''TorqueConverter: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2118.TorqueConverter.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to TorqueConverter. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new(_2118.TorqueConverter)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def system_deflection_results(self) -> '_2224.CouplingSystemDeflection':
        '''CouplingSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2224.CouplingSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_clutch_system_deflection(self) -> '_2206.ClutchSystemDeflection':
        '''ClutchSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2206.ClutchSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to ClutchSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2206.ClutchSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_concept_coupling_system_deflection(self) -> '_2212.ConceptCouplingSystemDeflection':
        '''ConceptCouplingSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2212.ConceptCouplingSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to ConceptCouplingSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2212.ConceptCouplingSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_part_to_part_shear_coupling_system_deflection(self) -> '_2273.PartToPartShearCouplingSystemDeflection':
        '''PartToPartShearCouplingSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2273.PartToPartShearCouplingSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to PartToPartShearCouplingSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2273.PartToPartShearCouplingSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_spring_damper_system_deflection(self) -> '_2294.SpringDamperSystemDeflection':
        '''SpringDamperSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2294.SpringDamperSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to SpringDamperSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2294.SpringDamperSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_torque_converter_system_deflection(self) -> '_2312.TorqueConverterSystemDeflection':
        '''TorqueConverterSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2312.TorqueConverterSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to TorqueConverterSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2312.TorqueConverterSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None



'''_6220.py

BeltConnectionAdvancedSystemDeflection
'''


from typing import List

from mastapy.system_model.connections_and_sockets import _1811
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6033
from mastapy.system_model.analyses_and_results.system_deflections import _2192
from mastapy.system_model.analyses_and_results.advanced_system_deflections import _6273
from mastapy._internal.python_net import python_net_import

_BELT_CONNECTION_ADVANCED_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections', 'BeltConnectionAdvancedSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('BeltConnectionAdvancedSystemDeflection',)


class BeltConnectionAdvancedSystemDeflection(_6273.InterMountableComponentConnectionAdvancedSystemDeflection):
    '''BeltConnectionAdvancedSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _BELT_CONNECTION_ADVANCED_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BeltConnectionAdvancedSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def connection_design(self) -> '_1811.BeltConnection':
        '''BeltConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1811.BeltConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_load_case(self) -> '_6033.BeltConnectionLoadCase':
        '''BeltConnectionLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6033.BeltConnectionLoadCase)(self.wrapped.ConnectionLoadCase) if self.wrapped.ConnectionLoadCase else None

    @property
    def connection_system_deflection_results(self) -> 'List[_2192.BeltConnectionSystemDeflection]':
        '''List[BeltConnectionSystemDeflection]: 'ConnectionSystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConnectionSystemDeflectionResults, constructor.new(_2192.BeltConnectionSystemDeflection))
        return value



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._5083 import AbstractMeasuredDynamicResponseAtTime
    from ._5084 import DynamicForceResultAtTime
    from ._5085 import DynamicForceVector3DResult
    from ._5086 import DynamicTorqueResultAtTime
    from ._5087 import DynamicTorqueVector3DResult



'''_1333.py

EnumWithBool
'''


from enum import Enum
from typing import Generic, TypeVar

from mastapy._internal import constructor
from mastapy import _1
from mastapy._internal.python_net import python_net_import

_ENUM_WITH_BOOL = python_net_import('SMT.MastaAPI.Utility.Property', 'EnumWithBool')


__docformat__ = 'restructuredtext en'
__all__ = ('EnumWithBool',)


T = TypeVar('T', bound='Enum')


class EnumWithBool(_1.APIBase, Generic[T]):
    '''EnumWithBool

    This is a mastapy class.

    Generic Types:
        T
    '''

    TYPE = _ENUM_WITH_BOOL

    __hash__ = None

    def __init__(self, instance_to_wrap: 'EnumWithBool.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Name



'''_31.py

ShaftProfilePoint
'''


from typing import Callable

from mastapy._internal import constructor
from mastapy._internal.implicit import overridable
from mastapy.shafts import _16
from mastapy import _1
from mastapy._internal.python_net import python_net_import

_SHAFT_PROFILE_POINT = python_net_import('SMT.MastaAPI.Shafts', 'ShaftProfilePoint')


__docformat__ = 'restructuredtext en'
__all__ = ('ShaftProfilePoint',)


class ShaftProfilePoint(_1.APIBase):
    '''ShaftProfilePoint

    This is a mastapy class.
    '''

    TYPE = _SHAFT_PROFILE_POINT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ShaftProfilePoint.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def offset(self) -> 'float':
        '''float: 'Offset' is the original name of this property.'''

        return self.wrapped.Offset

    @offset.setter
    def offset(self, value: 'float'):
        self.wrapped.Offset = float(value) if value else 0.0

    @property
    def delete(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'Delete' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Delete

    @property
    def insert(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'Insert' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Insert

    @property
    def fillet_radius(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'FilletRadius' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.FilletRadius) if self.wrapped.FilletRadius else None

    @fillet_radius.setter
    def fillet_radius(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.TYPE
        enclosed_type = overridable.Overridable_float.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0)
        self.wrapped.FilletRadius = value

    @property
    def diameter(self) -> 'float':
        '''float: 'Diameter' is the original name of this property.'''

        return self.wrapped.Diameter

    @diameter.setter
    def diameter(self, value: 'float'):
        self.wrapped.Diameter = float(value) if value else 0.0

    @property
    def stress_concentration_factors(self) -> '_16.ProfilePointFilletStressConcentrationFactors':
        '''ProfilePointFilletStressConcentrationFactors: 'StressConcentrationFactors' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_16.ProfilePointFilletStressConcentrationFactors)(self.wrapped.StressConcentrationFactors) if self.wrapped.StressConcentrationFactors else None



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._733 import KlingelnbergCycloPalloidHypoidGearDesign
    from ._734 import KlingelnbergCycloPalloidHypoidGearMeshDesign
    from ._735 import KlingelnbergCycloPalloidHypoidGearSetDesign
    from ._736 import KlingelnbergCycloPalloidHypoidMeshedGearDesign



'''_1829.py

PulleySocket
'''


from mastapy.system_model.connections_and_sockets import _1819
from mastapy._internal.python_net import python_net_import

_PULLEY_SOCKET = python_net_import('SMT.MastaAPI.SystemModel.ConnectionsAndSockets', 'PulleySocket')


__docformat__ = 'restructuredtext en'
__all__ = ('PulleySocket',)


class PulleySocket(_1819.CylindricalSocket):
    '''PulleySocket

    This is a mastapy class.
    '''

    TYPE = _PULLEY_SOCKET

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PulleySocket.TYPE'):
        super().__init__(instance_to_wrap)



'''_2709.py

BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed
'''


from typing import List

from mastapy.system_model.part_model.gears import _2033
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6037
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed import _2710, _2708, _2714
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_GEAR_SET_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesAtASpeed', 'BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed',)


class BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed(_2714.BevelGearSetSteadyStateSynchronousResponseAtASpeed):
    '''BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed

    This is a mastapy class.
    '''

    TYPE = _BEVEL_DIFFERENTIAL_GEAR_SET_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def assembly_design(self) -> '_2033.BevelDifferentialGearSet':
        '''BevelDifferentialGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2033.BevelDifferentialGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6037.BevelDifferentialGearSetLoadCase':
        '''BevelDifferentialGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6037.BevelDifferentialGearSetLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def bevel_differential_gears_steady_state_synchronous_response_at_a_speed(self) -> 'List[_2710.BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed]':
        '''List[BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed]: 'BevelDifferentialGearsSteadyStateSynchronousResponseAtASpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BevelDifferentialGearsSteadyStateSynchronousResponseAtASpeed, constructor.new(_2710.BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed))
        return value

    @property
    def bevel_differential_meshes_steady_state_synchronous_response_at_a_speed(self) -> 'List[_2708.BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed]':
        '''List[BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed]: 'BevelDifferentialMeshesSteadyStateSynchronousResponseAtASpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BevelDifferentialMeshesSteadyStateSynchronousResponseAtASpeed, constructor.new(_2708.BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed))
        return value



'''_1181.py

Impulse
'''


from mastapy.utility.units_and_measurements import _1138
from mastapy._internal.python_net import python_net_import

_IMPULSE = python_net_import('SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements', 'Impulse')


__docformat__ = 'restructuredtext en'
__all__ = ('Impulse',)


class Impulse(_1138.MeasurementBase):
    '''Impulse

    This is a mastapy class.
    '''

    TYPE = _IMPULSE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'Impulse.TYPE'):
        super().__init__(instance_to_wrap)



'''_949.py

GearSetGroupDutyCycle
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.gears.rating import _165
from mastapy import _1
from mastapy._internal.python_net import python_net_import

_GEAR_SET_GROUP_DUTY_CYCLE = python_net_import('SMT.MastaAPI.Gears.Analysis', 'GearSetGroupDutyCycle')


__docformat__ = 'restructuredtext en'
__all__ = ('GearSetGroupDutyCycle',)


class GearSetGroupDutyCycle(_1.APIBase):
    '''GearSetGroupDutyCycle

    This is a mastapy class.
    '''

    TYPE = _GEAR_SET_GROUP_DUTY_CYCLE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearSetGroupDutyCycle.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def analysis_name(self) -> 'str':
        '''str: 'AnalysisName' is the original name of this property.'''

        return self.wrapped.AnalysisName

    @analysis_name.setter
    def analysis_name(self, value: 'str'):
        self.wrapped.AnalysisName = str(value) if value else None

    @property
    def total_duration(self) -> 'float':
        '''float: 'TotalDuration' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TotalDuration

    @property
    def normalized_safety_factor_for_fatigue_and_static(self) -> 'float':
        '''float: 'NormalizedSafetyFactorForFatigueAndStatic' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalizedSafetyFactorForFatigueAndStatic

    @property
    def normalized_safety_factor_for_fatigue(self) -> 'float':
        '''float: 'NormalizedSafetyFactorForFatigue' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalizedSafetyFactorForFatigue

    @property
    def normalized_safety_factor_for_static(self) -> 'float':
        '''float: 'NormalizedSafetyFactorForStatic' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalizedSafetyFactorForStatic

    @property
    def normalized_bending_safety_factor_for_fatigue(self) -> 'float':
        '''float: 'NormalizedBendingSafetyFactorForFatigue' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalizedBendingSafetyFactorForFatigue

    @property
    def normalized_bending_safety_factor_for_static(self) -> 'float':
        '''float: 'NormalizedBendingSafetyFactorForStatic' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalizedBendingSafetyFactorForStatic

    @property
    def normalized_contact_safety_factor_for_fatigue(self) -> 'float':
        '''float: 'NormalizedContactSafetyFactorForFatigue' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalizedContactSafetyFactorForFatigue

    @property
    def normalized_contact_safety_factor_for_static(self) -> 'float':
        '''float: 'NormalizedContactSafetyFactorForStatic' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalizedContactSafetyFactorForStatic

    @property
    def loaded_rating_duty_cycles(self) -> 'List[_165.GearSetDutyCycleRating]':
        '''List[GearSetDutyCycleRating]: 'LoadedRatingDutyCycles' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.LoadedRatingDutyCycles, constructor.new(_165.GearSetDutyCycleRating))
        return value

    @property
    def rating_duty_cycles(self) -> 'List[_165.GearSetDutyCycleRating]':
        '''List[GearSetDutyCycleRating]: 'RatingDutyCycles' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.RatingDutyCycles, constructor.new(_165.GearSetDutyCycleRating))
        return value



'''_5332.py

PointLoadGearWhineAnalysis
'''


from mastapy.system_model.part_model import _1990
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6143
from mastapy.system_model.analyses_and_results.system_deflections import _2276
from mastapy.system_model.analyses_and_results.gear_whine_analyses import _5369
from mastapy._internal.python_net import python_net_import

_POINT_LOAD_GEAR_WHINE_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.GearWhineAnalyses', 'PointLoadGearWhineAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('PointLoadGearWhineAnalysis',)


class PointLoadGearWhineAnalysis(_5369.VirtualComponentGearWhineAnalysis):
    '''PointLoadGearWhineAnalysis

    This is a mastapy class.
    '''

    TYPE = _POINT_LOAD_GEAR_WHINE_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PointLoadGearWhineAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_1990.PointLoad':
        '''PointLoad: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1990.PointLoad)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6143.PointLoadLoadCase':
        '''PointLoadLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6143.PointLoadLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None

    @property
    def system_deflection_results(self) -> '_2276.PointLoadSystemDeflection':
        '''PointLoadSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2276.PointLoadSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None



'''_2016.py

CylindricalGearInPlanetarySetFromCAD
'''


from mastapy.system_model.part_model.import_from_cad import _2015
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_IN_PLANETARY_SET_FROM_CAD = python_net_import('SMT.MastaAPI.SystemModel.PartModel.ImportFromCAD', 'CylindricalGearInPlanetarySetFromCAD')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearInPlanetarySetFromCAD',)


class CylindricalGearInPlanetarySetFromCAD(_2015.CylindricalGearFromCAD):
    '''CylindricalGearInPlanetarySetFromCAD

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_IN_PLANETARY_SET_FROM_CAD

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearInPlanetarySetFromCAD.TYPE'):
        super().__init__(instance_to_wrap)



'''_5504.py

WormGearSetSingleMeshWhineAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2069
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6189
from mastapy.system_model.analyses_and_results.gear_whine_analyses.single_mesh_whine_analyses import _5505, _5503, _5438
from mastapy._internal.python_net import python_net_import

_WORM_GEAR_SET_SINGLE_MESH_WHINE_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.GearWhineAnalyses.SingleMeshWhineAnalyses', 'WormGearSetSingleMeshWhineAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('WormGearSetSingleMeshWhineAnalysis',)


class WormGearSetSingleMeshWhineAnalysis(_5438.GearSetSingleMeshWhineAnalysis):
    '''WormGearSetSingleMeshWhineAnalysis

    This is a mastapy class.
    '''

    TYPE = _WORM_GEAR_SET_SINGLE_MESH_WHINE_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'WormGearSetSingleMeshWhineAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def assembly_design(self) -> '_2069.WormGearSet':
        '''WormGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2069.WormGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6189.WormGearSetLoadCase':
        '''WormGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6189.WormGearSetLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def worm_gears_single_mesh_whine_analysis(self) -> 'List[_5505.WormGearSingleMeshWhineAnalysis]':
        '''List[WormGearSingleMeshWhineAnalysis]: 'WormGearsSingleMeshWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.WormGearsSingleMeshWhineAnalysis, constructor.new(_5505.WormGearSingleMeshWhineAnalysis))
        return value

    @property
    def worm_meshes_single_mesh_whine_analysis(self) -> 'List[_5503.WormGearMeshSingleMeshWhineAnalysis]':
        '''List[WormGearMeshSingleMeshWhineAnalysis]: 'WormMeshesSingleMeshWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.WormMeshesSingleMeshWhineAnalysis, constructor.new(_5503.WormGearMeshSingleMeshWhineAnalysis))
        return value



'''_1234.py

ThermalContactCoefficient
'''


from mastapy.utility.units_and_measurements import _1138
from mastapy._internal.python_net import python_net_import

_THERMAL_CONTACT_COEFFICIENT = python_net_import('SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements', 'ThermalContactCoefficient')


__docformat__ = 'restructuredtext en'
__all__ = ('ThermalContactCoefficient',)


class ThermalContactCoefficient(_1138.MeasurementBase):
    '''ThermalContactCoefficient

    This is a mastapy class.
    '''

    TYPE = _THERMAL_CONTACT_COEFFICIENT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ThermalContactCoefficient.TYPE'):
        super().__init__(instance_to_wrap)



'''_509.py

CylindricalGearRealCutterDesign
'''


from mastapy._internal import constructor
from mastapy._internal.implicit import overridable
from mastapy.scripting import _6482
from mastapy.gears.manufacturing.cylindrical.cutters.tangibles import (
    _519, _520, _521, _522,
    _523, _524, _526
)
from mastapy._internal.cast_exception import CastException
from mastapy.gears.manufacturing.cylindrical.cutters import _500, _502
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_REAL_CUTTER_DESIGN = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.Cutters', 'CylindricalGearRealCutterDesign')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearRealCutterDesign',)


class CylindricalGearRealCutterDesign(_502.CylindricalGearAbstractCutterDesign):
    '''CylindricalGearRealCutterDesign

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_REAL_CUTTER_DESIGN

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearRealCutterDesign.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def has_tolerances(self) -> 'bool':
        '''bool: 'HasTolerances' is the original name of this property.'''

        return self.wrapped.HasTolerances

    @has_tolerances.setter
    def has_tolerances(self, value: 'bool'):
        self.wrapped.HasTolerances = bool(value) if value else False

    @property
    def pitch_on_reference_cylinder(self) -> 'float':
        '''float: 'PitchOnReferenceCylinder' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PitchOnReferenceCylinder

    @property
    def normal_base_pitch(self) -> 'float':
        '''float: 'NormalBasePitch' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalBasePitch

    @property
    def number_of_points_for_reporting_fillet_shape(self) -> 'overridable.Overridable_int':
        '''overridable.Overridable_int: 'NumberOfPointsForReportingFilletShape' is the original name of this property.'''

        return constructor.new(overridable.Overridable_int)(self.wrapped.NumberOfPointsForReportingFilletShape) if self.wrapped.NumberOfPointsForReportingFilletShape else None

    @number_of_points_for_reporting_fillet_shape.setter
    def number_of_points_for_reporting_fillet_shape(self, value: 'overridable.Overridable_int.implicit_type()'):
        wrapper_type = overridable.Overridable_int.TYPE
        enclosed_type = overridable.Overridable_int.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0)
        self.wrapped.NumberOfPointsForReportingFilletShape = value

    @property
    def nominal_cutter_drawing(self) -> '_6482.SMTBitmap':
        '''SMTBitmap: 'NominalCutterDrawing' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6482.SMTBitmap)(self.wrapped.NominalCutterDrawing) if self.wrapped.NominalCutterDrawing else None

    @property
    def number_of_points_for_reporting_main_blade_shape(self) -> 'overridable.Overridable_int':
        '''overridable.Overridable_int: 'NumberOfPointsForReportingMainBladeShape' is the original name of this property.'''

        return constructor.new(overridable.Overridable_int)(self.wrapped.NumberOfPointsForReportingMainBladeShape) if self.wrapped.NumberOfPointsForReportingMainBladeShape else None

    @number_of_points_for_reporting_main_blade_shape.setter
    def number_of_points_for_reporting_main_blade_shape(self, value: 'overridable.Overridable_int.implicit_type()'):
        wrapper_type = overridable.Overridable_int.TYPE
        enclosed_type = overridable.Overridable_int.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0)
        self.wrapped.NumberOfPointsForReportingMainBladeShape = value

    @property
    def specify_custom_blade_shape(self) -> 'bool':
        '''bool: 'SpecifyCustomBladeShape' is the original name of this property.'''

        return self.wrapped.SpecifyCustomBladeShape

    @specify_custom_blade_shape.setter
    def specify_custom_blade_shape(self, value: 'bool'):
        self.wrapped.SpecifyCustomBladeShape = bool(value) if value else False

    @property
    def is_hob(self) -> 'bool':
        '''bool: 'IsHob' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IsHob

    @property
    def is_shaper(self) -> 'bool':
        '''bool: 'IsShaper' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IsShaper

    @property
    def cutter_and_gear_normal_base_pitch_comparison_tolerance(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'CutterAndGearNormalBasePitchComparisonTolerance' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.CutterAndGearNormalBasePitchComparisonTolerance) if self.wrapped.CutterAndGearNormalBasePitchComparisonTolerance else None

    @cutter_and_gear_normal_base_pitch_comparison_tolerance.setter
    def cutter_and_gear_normal_base_pitch_comparison_tolerance(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.TYPE
        enclosed_type = overridable.Overridable_float.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0)
        self.wrapped.CutterAndGearNormalBasePitchComparisonTolerance = value

    @property
    def nominal_cutter_shape(self) -> '_519.CutterShapeDefinition':
        '''CutterShapeDefinition: 'NominalCutterShape' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_519.CutterShapeDefinition)(self.wrapped.NominalCutterShape) if self.wrapped.NominalCutterShape else None

    @property
    def nominal_cutter_shape_of_type_cylindrical_gear_formed_wheel_grinder_tangible(self) -> '_520.CylindricalGearFormedWheelGrinderTangible':
        '''CylindricalGearFormedWheelGrinderTangible: 'NominalCutterShape' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _520.CylindricalGearFormedWheelGrinderTangible.TYPE not in self.wrapped.NominalCutterShape.__class__.__mro__:
            raise CastException('Failed to cast nominal_cutter_shape to CylindricalGearFormedWheelGrinderTangible. Expected: {}.'.format(self.wrapped.NominalCutterShape.__class__.__qualname__))

        return constructor.new(_520.CylindricalGearFormedWheelGrinderTangible)(self.wrapped.NominalCutterShape) if self.wrapped.NominalCutterShape else None

    @property
    def nominal_cutter_shape_of_type_cylindrical_gear_hob_shape(self) -> '_521.CylindricalGearHobShape':
        '''CylindricalGearHobShape: 'NominalCutterShape' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _521.CylindricalGearHobShape.TYPE not in self.wrapped.NominalCutterShape.__class__.__mro__:
            raise CastException('Failed to cast nominal_cutter_shape to CylindricalGearHobShape. Expected: {}.'.format(self.wrapped.NominalCutterShape.__class__.__qualname__))

        return constructor.new(_521.CylindricalGearHobShape)(self.wrapped.NominalCutterShape) if self.wrapped.NominalCutterShape else None

    @property
    def nominal_cutter_shape_of_type_cylindrical_gear_shaper_tangible(self) -> '_522.CylindricalGearShaperTangible':
        '''CylindricalGearShaperTangible: 'NominalCutterShape' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _522.CylindricalGearShaperTangible.TYPE not in self.wrapped.NominalCutterShape.__class__.__mro__:
            raise CastException('Failed to cast nominal_cutter_shape to CylindricalGearShaperTangible. Expected: {}.'.format(self.wrapped.NominalCutterShape.__class__.__qualname__))

        return constructor.new(_522.CylindricalGearShaperTangible)(self.wrapped.NominalCutterShape) if self.wrapped.NominalCutterShape else None

    @property
    def nominal_cutter_shape_of_type_cylindrical_gear_shaver_tangible(self) -> '_523.CylindricalGearShaverTangible':
        '''CylindricalGearShaverTangible: 'NominalCutterShape' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _523.CylindricalGearShaverTangible.TYPE not in self.wrapped.NominalCutterShape.__class__.__mro__:
            raise CastException('Failed to cast nominal_cutter_shape to CylindricalGearShaverTangible. Expected: {}.'.format(self.wrapped.NominalCutterShape.__class__.__qualname__))

        return constructor.new(_523.CylindricalGearShaverTangible)(self.wrapped.NominalCutterShape) if self.wrapped.NominalCutterShape else None

    @property
    def nominal_cutter_shape_of_type_cylindrical_gear_worm_grinder_shape(self) -> '_524.CylindricalGearWormGrinderShape':
        '''CylindricalGearWormGrinderShape: 'NominalCutterShape' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _524.CylindricalGearWormGrinderShape.TYPE not in self.wrapped.NominalCutterShape.__class__.__mro__:
            raise CastException('Failed to cast nominal_cutter_shape to CylindricalGearWormGrinderShape. Expected: {}.'.format(self.wrapped.NominalCutterShape.__class__.__qualname__))

        return constructor.new(_524.CylindricalGearWormGrinderShape)(self.wrapped.NominalCutterShape) if self.wrapped.NominalCutterShape else None

    @property
    def nominal_cutter_shape_of_type_rack_shape(self) -> '_526.RackShape':
        '''RackShape: 'NominalCutterShape' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _526.RackShape.TYPE not in self.wrapped.NominalCutterShape.__class__.__mro__:
            raise CastException('Failed to cast nominal_cutter_shape to RackShape. Expected: {}.'.format(self.wrapped.NominalCutterShape.__class__.__qualname__))

        return constructor.new(_526.RackShape)(self.wrapped.NominalCutterShape) if self.wrapped.NominalCutterShape else None

    @property
    def customised_cutting_edge_profile(self) -> '_500.CustomisableEdgeProfile':
        '''CustomisableEdgeProfile: 'CustomisedCuttingEdgeProfile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_500.CustomisableEdgeProfile)(self.wrapped.CustomisedCuttingEdgeProfile) if self.wrapped.CustomisedCuttingEdgeProfile else None



'''_1663.py

SKFMaximalConstantlyActingAxialLoadResults
'''


from mastapy._internal import constructor
from mastapy import _1
from mastapy._internal.python_net import python_net_import

_SKF_MAXIMAL_CONSTANTLY_ACTING_AXIAL_LOAD_RESULTS = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling', 'SKFMaximalConstantlyActingAxialLoadResults')


__docformat__ = 'restructuredtext en'
__all__ = ('SKFMaximalConstantlyActingAxialLoadResults',)


class SKFMaximalConstantlyActingAxialLoadResults(_1.APIBase):
    '''SKFMaximalConstantlyActingAxialLoadResults

    This is a mastapy class.
    '''

    TYPE = _SKF_MAXIMAL_CONSTANTLY_ACTING_AXIAL_LOAD_RESULTS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SKFMaximalConstantlyActingAxialLoadResults.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def limiting_axial_load_as_a_function_of_diameter(self) -> 'float':
        '''float: 'LimitingAxialLoadAsAFunctionOfDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LimitingAxialLoadAsAFunctionOfDiameter

    @property
    def axial_load(self) -> 'float':
        '''float: 'AxialLoad' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AxialLoad

    @property
    def safety_factor(self) -> 'float':
        '''float: 'SafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SafetyFactor



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._3944 import AbstractAssemblyModalAnalysesAtSpeeds
    from ._3945 import AbstractShaftOrHousingModalAnalysesAtSpeeds
    from ._3946 import AGMAGleasonConicalGearMeshModalAnalysesAtSpeeds
    from ._3947 import AGMAGleasonConicalGearModalAnalysesAtSpeeds
    from ._3948 import AGMAGleasonConicalGearSetModalAnalysesAtSpeeds
    from ._3949 import AssemblyModalAnalysesAtSpeeds
    from ._3950 import BearingModalAnalysesAtSpeeds
    from ._3951 import BeltConnectionModalAnalysesAtSpeeds
    from ._3952 import BeltDriveModalAnalysesAtSpeeds
    from ._3953 import BevelDifferentialGearMeshModalAnalysesAtSpeeds
    from ._3954 import BevelDifferentialGearModalAnalysesAtSpeeds
    from ._3955 import BevelDifferentialGearSetModalAnalysesAtSpeeds
    from ._3956 import BevelDifferentialPlanetGearModalAnalysesAtSpeeds
    from ._3957 import BevelDifferentialSunGearModalAnalysesAtSpeeds
    from ._3958 import BevelGearMeshModalAnalysesAtSpeeds
    from ._3959 import BevelGearModalAnalysesAtSpeeds
    from ._3960 import BevelGearSetModalAnalysesAtSpeeds
    from ._3961 import BoltedJointModalAnalysesAtSpeeds
    from ._3962 import BoltModalAnalysesAtSpeeds
    from ._3963 import ClutchConnectionModalAnalysesAtSpeeds
    from ._3964 import ClutchHalfModalAnalysesAtSpeeds
    from ._3965 import ClutchModalAnalysesAtSpeeds
    from ._3966 import CoaxialConnectionModalAnalysesAtSpeeds
    from ._3967 import ComponentModalAnalysesAtSpeeds
    from ._3968 import ConceptCouplingConnectionModalAnalysesAtSpeeds
    from ._3969 import ConceptCouplingHalfModalAnalysesAtSpeeds
    from ._3970 import ConceptCouplingModalAnalysesAtSpeeds
    from ._3971 import ConceptGearMeshModalAnalysesAtSpeeds
    from ._3972 import ConceptGearModalAnalysesAtSpeeds
    from ._3973 import ConceptGearSetModalAnalysesAtSpeeds
    from ._3974 import ConicalGearMeshModalAnalysesAtSpeeds
    from ._3975 import ConicalGearModalAnalysesAtSpeeds
    from ._3976 import ConicalGearSetModalAnalysesAtSpeeds
    from ._3977 import ConnectionModalAnalysesAtSpeeds
    from ._3978 import ConnectorModalAnalysesAtSpeeds
    from ._3979 import CouplingConnectionModalAnalysesAtSpeeds
    from ._3980 import CouplingHalfModalAnalysesAtSpeeds
    from ._3981 import CouplingModalAnalysesAtSpeeds
    from ._3982 import CVTBeltConnectionModalAnalysesAtSpeeds
    from ._3983 import CVTModalAnalysesAtSpeeds
    from ._3984 import CVTPulleyModalAnalysesAtSpeeds
    from ._3985 import CylindricalGearMeshModalAnalysesAtSpeeds
    from ._3986 import CylindricalGearModalAnalysesAtSpeeds
    from ._3987 import CylindricalGearSetModalAnalysesAtSpeeds
    from ._3988 import CylindricalPlanetGearModalAnalysesAtSpeeds
    from ._3989 import DatumModalAnalysesAtSpeeds
    from ._3990 import DynamicModelForAtSpeeds
    from ._3991 import ExternalCADModelModalAnalysesAtSpeeds
    from ._3992 import FaceGearMeshModalAnalysesAtSpeeds
    from ._3993 import FaceGearModalAnalysesAtSpeeds
    from ._3994 import FaceGearSetModalAnalysesAtSpeeds
    from ._3995 import FlexiblePinAssemblyModalAnalysesAtSpeeds
    from ._3996 import GearMeshModalAnalysesAtSpeeds
    from ._3997 import GearModalAnalysesAtSpeeds
    from ._3998 import GearSetModalAnalysesAtSpeeds
    from ._3999 import GuideDxfModelModalAnalysesAtSpeeds
    from ._4000 import HypoidGearMeshModalAnalysesAtSpeeds
    from ._4001 import HypoidGearModalAnalysesAtSpeeds
    from ._4002 import HypoidGearSetModalAnalysesAtSpeeds
    from ._4003 import ImportedFEComponentModalAnalysesAtSpeeds
    from ._4004 import InterMountableComponentConnectionModalAnalysesAtSpeeds
    from ._4005 import KlingelnbergCycloPalloidConicalGearMeshModalAnalysesAtSpeeds
    from ._4006 import KlingelnbergCycloPalloidConicalGearModalAnalysesAtSpeeds
    from ._4007 import KlingelnbergCycloPalloidConicalGearSetModalAnalysesAtSpeeds
    from ._4008 import KlingelnbergCycloPalloidHypoidGearMeshModalAnalysesAtSpeeds
    from ._4009 import KlingelnbergCycloPalloidHypoidGearModalAnalysesAtSpeeds
    from ._4010 import KlingelnbergCycloPalloidHypoidGearSetModalAnalysesAtSpeeds
    from ._4011 import KlingelnbergCycloPalloidSpiralBevelGearMeshModalAnalysesAtSpeeds
    from ._4012 import KlingelnbergCycloPalloidSpiralBevelGearModalAnalysesAtSpeeds
    from ._4013 import KlingelnbergCycloPalloidSpiralBevelGearSetModalAnalysesAtSpeeds
    from ._4014 import MassDiscModalAnalysesAtSpeeds
    from ._4015 import MeasurementComponentModalAnalysesAtSpeeds
    from ._4016 import ModalAnalysesAtSpeedsOptions
    from ._4017 import ModalAnalysisAtSpeedsDrawStyle
    from ._4018 import MountableComponentModalAnalysesAtSpeeds
    from ._4019 import OilSealModalAnalysesAtSpeeds
    from ._4020 import PartModalAnalysesAtSpeeds
    from ._4021 import PartToPartShearCouplingConnectionModalAnalysesAtSpeeds
    from ._4022 import PartToPartShearCouplingHalfModalAnalysesAtSpeeds
    from ._4023 import PartToPartShearCouplingModalAnalysesAtSpeeds
    from ._4024 import PlanetaryConnectionModalAnalysesAtSpeeds
    from ._4025 import PlanetaryGearSetModalAnalysesAtSpeeds
    from ._4026 import PlanetCarrierModalAnalysesAtSpeeds
    from ._4027 import PointLoadModalAnalysesAtSpeeds
    from ._4028 import PowerLoadModalAnalysesAtSpeeds
    from ._4029 import PulleyModalAnalysesAtSpeeds
    from ._4030 import RollingRingAssemblyModalAnalysesAtSpeeds
    from ._4031 import RollingRingConnectionModalAnalysesAtSpeeds
    from ._4032 import RollingRingModalAnalysesAtSpeeds
    from ._4033 import RootAssemblyModalAnalysesAtSpeeds
    from ._4034 import ShaftHubConnectionModalAnalysesAtSpeeds
    from ._4035 import ShaftModalAnalysesAtSpeeds
    from ._4036 import ShaftToMountableComponentConnectionModalAnalysesAtSpeeds
    from ._4037 import SpecialisedAssemblyModalAnalysesAtSpeeds
    from ._4038 import SpiralBevelGearMeshModalAnalysesAtSpeeds
    from ._4039 import SpiralBevelGearModalAnalysesAtSpeeds
    from ._4040 import SpiralBevelGearSetModalAnalysesAtSpeeds
    from ._4041 import SpringDamperConnectionModalAnalysesAtSpeeds
    from ._4042 import SpringDamperHalfModalAnalysesAtSpeeds
    from ._4043 import SpringDamperModalAnalysesAtSpeeds
    from ._4044 import StabilityAnalysis
    from ._4045 import StraightBevelDiffGearMeshModalAnalysesAtSpeeds
    from ._4046 import StraightBevelDiffGearModalAnalysesAtSpeeds
    from ._4047 import StraightBevelDiffGearSetModalAnalysesAtSpeeds
    from ._4048 import StraightBevelGearMeshModalAnalysesAtSpeeds
    from ._4049 import StraightBevelGearModalAnalysesAtSpeeds
    from ._4050 import StraightBevelGearSetModalAnalysesAtSpeeds
    from ._4051 import StraightBevelPlanetGearModalAnalysesAtSpeeds
    from ._4052 import StraightBevelSunGearModalAnalysesAtSpeeds
    from ._4053 import SynchroniserHalfModalAnalysesAtSpeeds
    from ._4054 import SynchroniserModalAnalysesAtSpeeds
    from ._4055 import SynchroniserPartModalAnalysesAtSpeeds
    from ._4056 import SynchroniserSleeveModalAnalysesAtSpeeds
    from ._4057 import TorqueConverterConnectionModalAnalysesAtSpeeds
    from ._4058 import TorqueConverterModalAnalysesAtSpeeds
    from ._4059 import TorqueConverterPumpModalAnalysesAtSpeeds
    from ._4060 import TorqueConverterTurbineModalAnalysesAtSpeeds
    from ._4061 import UnbalancedMassModalAnalysesAtSpeeds
    from ._4062 import VirtualComponentModalAnalysesAtSpeeds
    from ._4063 import WormGearMeshModalAnalysesAtSpeeds
    from ._4064 import WormGearModalAnalysesAtSpeeds
    from ._4065 import WormGearSetModalAnalysesAtSpeeds
    from ._4066 import ZerolBevelGearMeshModalAnalysesAtSpeeds
    from ._4067 import ZerolBevelGearModalAnalysesAtSpeeds
    from ._4068 import ZerolBevelGearSetModalAnalysesAtSpeeds



'''_2230.py

CylindricalGearMeshSystemDeflectionWithLTCAResults
'''


from mastapy.gears.ltca.cylindrical import _624
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.system_deflections import _2228
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_MESH_SYSTEM_DEFLECTION_WITH_LTCA_RESULTS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections', 'CylindricalGearMeshSystemDeflectionWithLTCAResults')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearMeshSystemDeflectionWithLTCAResults',)


class CylindricalGearMeshSystemDeflectionWithLTCAResults(_2228.CylindricalGearMeshSystemDeflection):
    '''CylindricalGearMeshSystemDeflectionWithLTCAResults

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_MESH_SYSTEM_DEFLECTION_WITH_LTCA_RESULTS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearMeshSystemDeflectionWithLTCAResults.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def basic_ltca_results(self) -> '_624.CylindricalGearMeshLoadDistributionAnalysis':
        '''CylindricalGearMeshLoadDistributionAnalysis: 'BasicLTCAResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_624.CylindricalGearMeshLoadDistributionAnalysis)(self.wrapped.BasicLTCAResults) if self.wrapped.BasicLTCAResults else None

    @property
    def basic_ltca_results_only_first_planetary_mesh(self) -> '_624.CylindricalGearMeshLoadDistributionAnalysis':
        '''CylindricalGearMeshLoadDistributionAnalysis: 'BasicLTCAResultsOnlyFirstPlanetaryMesh' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_624.CylindricalGearMeshLoadDistributionAnalysis)(self.wrapped.BasicLTCAResultsOnlyFirstPlanetaryMesh) if self.wrapped.BasicLTCAResultsOnlyFirstPlanetaryMesh else None

    @property
    def advanced_ltca_results(self) -> '_624.CylindricalGearMeshLoadDistributionAnalysis':
        '''CylindricalGearMeshLoadDistributionAnalysis: 'AdvancedLTCAResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_624.CylindricalGearMeshLoadDistributionAnalysis)(self.wrapped.AdvancedLTCAResults) if self.wrapped.AdvancedLTCAResults else None

    @property
    def advanced_ltca_results_only_first_planetary_mesh(self) -> '_624.CylindricalGearMeshLoadDistributionAnalysis':
        '''CylindricalGearMeshLoadDistributionAnalysis: 'AdvancedLTCAResultsOnlyFirstPlanetaryMesh' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_624.CylindricalGearMeshLoadDistributionAnalysis)(self.wrapped.AdvancedLTCAResultsOnlyFirstPlanetaryMesh) if self.wrapped.AdvancedLTCAResultsOnlyFirstPlanetaryMesh else None



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2130 import CompoundAnalysis
    from ._2131 import SingleAnalysis
    from ._2132 import AdvancedSystemDeflectionAnalysis
    from ._2133 import AdvancedSystemDeflectionSubAnalysisAnalysis
    from ._2134 import CompoundParametricStudyToolAnalysis
    from ._2135 import DynamicAnalysisAnalysis
    from ._2136 import DynamicModelataStiffnessAnalysis
    from ._2137 import DynamicModelforatSpeedsAnalysis
    from ._2138 import DynamicModelforGearWhineAnalysis
    from ._2139 import DynamicModelforSteadyStateSynchronousResponseAnalysis
    from ._2140 import GearWhineAnalysisAnalysis
    from ._2141 import ModalAnalysesataSpeedAnalysis
    from ._2142 import ModalAnalysesataStiffnessAnalysis
    from ._2143 import ModalAnalysesatSpeedsAnalysis
    from ._2144 import ModalAnalysesatStiffnessesAnalysis
    from ._2145 import ModalAnalysisAnalysis
    from ._2146 import ModalAnalysisforWhineAnalysis
    from ._2147 import MultibodyDynamicsAnalysis
    from ._2148 import ParametricStudyToolAnalysis
    from ._2149 import PowerFlowAnalysis
    from ._2150 import SingleMeshWhineAnalysisAnalysis
    from ._2151 import SteadyStateSynchronousResponseAnalysis
    from ._2152 import SteadyStateSynchronousResponseataSpeedAnalysis
    from ._2153 import SteadyStateSynchronousResponseonaShaftAnalysis
    from ._2154 import SystemDeflectionAnalysis
    from ._2155 import TorsionalSystemDeflectionAnalysis
    from ._2156 import AnalysisCaseVariable
    from ._2157 import ConnectionAnalysis
    from ._2158 import Context
    from ._2159 import DesignEntityAnalysis
    from ._2160 import DesignEntityGroupAnalysis
    from ._2161 import DesignEntitySingleContextAnalysis
    from ._2162 import PartAnalysis
    from ._2163 import CompoundAdvancedSystemDeflectionAnalysis
    from ._2164 import CompoundAdvancedSystemDeflectionSubAnalysisAnalysis
    from ._2165 import CompoundDynamicAnalysisAnalysis
    from ._2166 import CompoundDynamicModelataStiffnessAnalysis
    from ._2167 import CompoundDynamicModelforatSpeedsAnalysis
    from ._2168 import CompoundDynamicModelforGearWhineAnalysis
    from ._2169 import CompoundDynamicModelforSteadyStateSynchronousResponseAnalysis
    from ._2170 import CompoundGearWhineAnalysisAnalysis
    from ._2171 import CompoundModalAnalysesataSpeedAnalysis
    from ._2172 import CompoundModalAnalysesataStiffnessAnalysis
    from ._2173 import CompoundModalAnalysesatSpeedsAnalysis
    from ._2174 import CompoundModalAnalysesatStiffnessesAnalysis
    from ._2175 import CompoundModalAnalysisAnalysis
    from ._2176 import CompoundModalAnalysisforWhineAnalysis
    from ._2177 import CompoundMultibodyDynamicsAnalysis
    from ._2178 import CompoundPowerFlowAnalysis
    from ._2179 import CompoundSingleMeshWhineAnalysisAnalysis
    from ._2180 import CompoundSteadyStateSynchronousResponseAnalysis
    from ._2181 import CompoundSteadyStateSynchronousResponseataSpeedAnalysis
    from ._2182 import CompoundSteadyStateSynchronousResponseonaShaftAnalysis
    from ._2183 import CompoundSystemDeflectionAnalysis
    from ._2184 import CompoundTorsionalSystemDeflectionAnalysis



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2699 import AbstractAssemblySteadyStateSynchronousResponseAtASpeed
    from ._2700 import AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed
    from ._2701 import AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2702 import AGMAGleasonConicalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2703 import AGMAGleasonConicalGearSteadyStateSynchronousResponseAtASpeed
    from ._2704 import AssemblySteadyStateSynchronousResponseAtASpeed
    from ._2705 import BearingSteadyStateSynchronousResponseAtASpeed
    from ._2706 import BeltConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2707 import BeltDriveSteadyStateSynchronousResponseAtASpeed
    from ._2708 import BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2709 import BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2710 import BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed
    from ._2711 import BevelDifferentialPlanetGearSteadyStateSynchronousResponseAtASpeed
    from ._2712 import BevelDifferentialSunGearSteadyStateSynchronousResponseAtASpeed
    from ._2713 import BevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2714 import BevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2715 import BevelGearSteadyStateSynchronousResponseAtASpeed
    from ._2716 import BoltedJointSteadyStateSynchronousResponseAtASpeed
    from ._2717 import BoltSteadyStateSynchronousResponseAtASpeed
    from ._2718 import ClutchConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2719 import ClutchHalfSteadyStateSynchronousResponseAtASpeed
    from ._2720 import ClutchSteadyStateSynchronousResponseAtASpeed
    from ._2721 import CoaxialConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2722 import ComponentSteadyStateSynchronousResponseAtASpeed
    from ._2723 import ConceptCouplingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2724 import ConceptCouplingHalfSteadyStateSynchronousResponseAtASpeed
    from ._2725 import ConceptCouplingSteadyStateSynchronousResponseAtASpeed
    from ._2726 import ConceptGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2727 import ConceptGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2728 import ConceptGearSteadyStateSynchronousResponseAtASpeed
    from ._2729 import ConicalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2730 import ConicalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2731 import ConicalGearSteadyStateSynchronousResponseAtASpeed
    from ._2732 import ConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2733 import ConnectorSteadyStateSynchronousResponseAtASpeed
    from ._2734 import CouplingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2735 import CouplingHalfSteadyStateSynchronousResponseAtASpeed
    from ._2736 import CouplingSteadyStateSynchronousResponseAtASpeed
    from ._2737 import CVTBeltConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2738 import CVTPulleySteadyStateSynchronousResponseAtASpeed
    from ._2739 import CVTSteadyStateSynchronousResponseAtASpeed
    from ._2740 import CylindricalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2741 import CylindricalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2742 import CylindricalGearSteadyStateSynchronousResponseAtASpeed
    from ._2743 import CylindricalPlanetGearSteadyStateSynchronousResponseAtASpeed
    from ._2744 import DatumSteadyStateSynchronousResponseAtASpeed
    from ._2745 import ExternalCADModelSteadyStateSynchronousResponseAtASpeed
    from ._2746 import FaceGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2747 import FaceGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2748 import FaceGearSteadyStateSynchronousResponseAtASpeed
    from ._2749 import FlexiblePinAssemblySteadyStateSynchronousResponseAtASpeed
    from ._2750 import GearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2751 import GearSetSteadyStateSynchronousResponseAtASpeed
    from ._2752 import GearSteadyStateSynchronousResponseAtASpeed
    from ._2753 import GuideDxfModelSteadyStateSynchronousResponseAtASpeed
    from ._2754 import HypoidGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2755 import HypoidGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2756 import HypoidGearSteadyStateSynchronousResponseAtASpeed
    from ._2757 import ImportedFEComponentSteadyStateSynchronousResponseAtASpeed
    from ._2758 import InterMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2759 import KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2760 import KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2761 import KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseAtASpeed
    from ._2762 import KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2763 import KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2764 import KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed
    from ._2765 import KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2766 import KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2767 import KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseAtASpeed
    from ._2768 import MassDiscSteadyStateSynchronousResponseAtASpeed
    from ._2769 import MeasurementComponentSteadyStateSynchronousResponseAtASpeed
    from ._2770 import MountableComponentSteadyStateSynchronousResponseAtASpeed
    from ._2771 import OilSealSteadyStateSynchronousResponseAtASpeed
    from ._2772 import PartSteadyStateSynchronousResponseAtASpeed
    from ._2773 import PartToPartShearCouplingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2774 import PartToPartShearCouplingHalfSteadyStateSynchronousResponseAtASpeed
    from ._2775 import PartToPartShearCouplingSteadyStateSynchronousResponseAtASpeed
    from ._2776 import PlanetaryConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2777 import PlanetaryGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2778 import PlanetCarrierSteadyStateSynchronousResponseAtASpeed
    from ._2779 import PointLoadSteadyStateSynchronousResponseAtASpeed
    from ._2780 import PowerLoadSteadyStateSynchronousResponseAtASpeed
    from ._2781 import PulleySteadyStateSynchronousResponseAtASpeed
    from ._2782 import RollingRingAssemblySteadyStateSynchronousResponseAtASpeed
    from ._2783 import RollingRingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2784 import RollingRingSteadyStateSynchronousResponseAtASpeed
    from ._2785 import RootAssemblySteadyStateSynchronousResponseAtASpeed
    from ._2786 import ShaftHubConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2787 import ShaftSteadyStateSynchronousResponseAtASpeed
    from ._2788 import ShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2789 import SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed
    from ._2790 import SpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2791 import SpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2792 import SpiralBevelGearSteadyStateSynchronousResponseAtASpeed
    from ._2793 import SpringDamperConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2794 import SpringDamperHalfSteadyStateSynchronousResponseAtASpeed
    from ._2795 import SpringDamperSteadyStateSynchronousResponseAtASpeed
    from ._2796 import SteadyStateSynchronousResponseAtASpeed
    from ._2797 import StraightBevelDiffGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2798 import StraightBevelDiffGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2799 import StraightBevelDiffGearSteadyStateSynchronousResponseAtASpeed
    from ._2800 import StraightBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2801 import StraightBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2802 import StraightBevelGearSteadyStateSynchronousResponseAtASpeed
    from ._2803 import StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed
    from ._2804 import StraightBevelSunGearSteadyStateSynchronousResponseAtASpeed
    from ._2805 import SynchroniserHalfSteadyStateSynchronousResponseAtASpeed
    from ._2806 import SynchroniserPartSteadyStateSynchronousResponseAtASpeed
    from ._2807 import SynchroniserSleeveSteadyStateSynchronousResponseAtASpeed
    from ._2808 import SynchroniserSteadyStateSynchronousResponseAtASpeed
    from ._2809 import TorqueConverterConnectionSteadyStateSynchronousResponseAtASpeed
    from ._2810 import TorqueConverterPumpSteadyStateSynchronousResponseAtASpeed
    from ._2811 import TorqueConverterSteadyStateSynchronousResponseAtASpeed
    from ._2812 import TorqueConverterTurbineSteadyStateSynchronousResponseAtASpeed
    from ._2813 import UnbalancedMassSteadyStateSynchronousResponseAtASpeed
    from ._2814 import VirtualComponentSteadyStateSynchronousResponseAtASpeed
    from ._2815 import WormGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2816 import WormGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2817 import WormGearSteadyStateSynchronousResponseAtASpeed
    from ._2818 import ZerolBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._2819 import ZerolBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._2820 import ZerolBevelGearSteadyStateSynchronousResponseAtASpeed



'''_5820.py

DynamicAnalysisDrawStyle
'''


from mastapy._internal import constructor
from mastapy.system_model.drawing import _1805
from mastapy._internal.python_net import python_net_import

_DYNAMIC_ANALYSIS_DRAW_STYLE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.DynamicAnalyses', 'DynamicAnalysisDrawStyle')


__docformat__ = 'restructuredtext en'
__all__ = ('DynamicAnalysisDrawStyle',)


class DynamicAnalysisDrawStyle(_1805.ContourDrawStyle):
    '''DynamicAnalysisDrawStyle

    This is a mastapy class.
    '''

    TYPE = _DYNAMIC_ANALYSIS_DRAW_STYLE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'DynamicAnalysisDrawStyle.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def animate_contour(self) -> 'bool':
        '''bool: 'AnimateContour' is the original name of this property.'''

        return self.wrapped.AnimateContour

    @animate_contour.setter
    def animate_contour(self, value: 'bool'):
        self.wrapped.AnimateContour = bool(value) if value else False
